==> ibm_whcs_sdk-0.0.5-py3-none-any.whl: ibm_whcs_sdk/insights_for_medical_literature/__init__.py <==
# Copyright 2018 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .insights_for_medical_literature_v1 import InsightsForMedicalLiteratureServiceV1
from .insights_for_medical_literature_v1 import AggregationModel
from .insights_for_medical_literature_v1 import Aggregations
from .insights_for_medical_literature_v1 import AnnotationModel
from .insights_for_medical_literature_v1 import ArtifactModel
from .insights_for_medical_literature_v1 import Attribute
from .insights_for_medical_literature_v1 import AttributeEntry
from .insights_for_medical_literature_v1 import Attributes
from .insights_for_medical_literature_v1 import BooleanConcepts
from .insights_for_medical_literature_v1 import CategoriesModel
from .insights_for_medical_literature_v1 import Category
from .insights_for_medical_literature_v1 import Concept
from .insights_for_medical_literature_v1 import ConceptInfoModel
from .insights_for_medical_literature_v1 import ConceptListModel
from .insights_for_medical_literature_v1 import ConceptModel
from .insights_for_medical_literature_v1 import Concepts
from .insights_for_medical_literature_v1 import CorporaConfigModel
from .insights_for_medical_literature_v1 import Corpus
from .insights_for_medical_literature_v1 import CorpusInfoModel
from .insights_for_medical_literature_v1 import CorpusProvider
from .insights_for_medical_literature_v1 import Count
from .insights_for_medical_literature_v1 import DateHistograms
from .insights_for_medical_literature_v1 import DictionaryEntry
from .insights_for_medical_literature_v1 import DocumentTextModel
from .insights_for_medical_literature_v1 import Documents
from .insights_for_medical_literature_v1 import EntryModel
from .insights_for_medical_literature_v1 import HitCount
from .insights_for_medical_literature_v1 import MetadataModel
from .insights_for_medical_literature_v1 import Order
from .insights_for_medical_literature_v1 import Passage
from .insights_for_medical_literature_v1 import Passages
from .insights_for_medical_literature_v1 import PossibleValues
from .insights_for_medical_literature_v1 import Qualifier
from .insights_for_medical_literature_v1 import Query
from .insights_for_medical_literature_v1 import Range
from .insights_for_medical_literature_v1 import Ranges
from .insights_for_medical_literature_v1 import RankedDocLinks
from .insights_for_medical_literature_v1 import RankedDocument
from .insights_for_medical_literature_v1 import RelatedConceptModel
from .insights_for_medical_literature_v1 import RelatedConceptsModel
from .insights_for_medical_literature_v1 import ReturnsModel
from .insights_for_medical_literature_v1 import SearchableConcept
from .insights_for_medical_literature_v1 import SearchMatchesModel
from .insights_for_medical_literature_v1 import SearchModel
from .insights_for_medical_literature_v1 import SentenceModel
from .insights_for_medical_literature_v1 import ServiceStatus
from .insights_for_medical_literature_v1 import SortEntry
from .insights_for_medical_literature_v1 import StringBuilder
from .insights_for_medical_literature_v1 import Supports
from .insights_for_medical_literature_v1 import Title
from .insights_for_medical_literature_v1 import Typeahead
from .insights_for_medical_literature_v1 import TypesModel
from .insights_for_medical_literature_v1 import Values
from .insights_for_medical_literature_v1 import YearAndHits
from .insights_for_medical_literature_v1 import IMLException

==> ibm_whcs_sdk-1.4.0-py3-none-any.whl: ibm_whcs_sdk/insights_for_medical_literature/__init__.py <==
# Copyright 2018 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .insights_for_medical_literature_v1 import InsightsForMedicalLiteratureServiceV1
from .insights_for_medical_literature_v1 import AggregationModel
from .insights_for_medical_literature_v1 import Aggregations
from .insights_for_medical_literature_v1 import AnnotationModel
from .insights_for_medical_literature_v1 import ArtifactModel
from .insights_for_medical_literature_v1 import Attribute
from .insights_for_medical_literature_v1 import AttributeEntry
from .insights_for_medical_literature_v1 import Attributes
from .insights_for_medical_literature_v1 import Backend
from .insights_for_medical_literature_v1 import BooleanConcepts
from .insights_for_medical_literature_v1 import BooleanOperands
from .insights_for_medical_literature_v1 import BoolOperand
from .insights_for_medical_literature_v1 import CategoriesModel
from .insights_for_medical_literature_v1 import Category
from .insights_for_medical_literature_v1 import CommonDataModel
from .insights_for_medical_literature_v1 import Concept
from .insights_for_medical_literature_v1 import ConceptInfoModel
from .insights_for_medical_literature_v1 import ConceptListModel
from .insights_for_medical_literature_v1 import ConceptModel
from .insights_for_medical_literature_v1 import Concepts
from .insights_for_medical_literature_v1 import CorporaConfigModel
from .insights_for_medical_literature_v1 import CorpusModel
from .insights_for_medical_literature_v1 import CorpusInfoModel
#from .insights_for_medical_literature_v1 import CorpusProvider
from .insights_for_medical_literature_v1 import Count
from .insights_for_medical_literature_v1 import DataModel
from .insights_for_medical_literature_v1 import DateHistograms
from .insights_for_medical_literature_v1 import DictionaryEntry
from .insights_for_medical_literature_v1 import Documents
from .insights_for_medical_literature_v1 import EntryModel
from .insights_for_medical_literature_v1 import FieldOptions
from .insights_for_medical_literature_v1 import GetDocumentInfoResponse
from .insights_for_medical_literature_v1 import HistogramData
from .insights_for_medical_literature_v1 import HitCount
from .insights_for_medical_literature_v1 import MetadataFields
from .insights_for_medical_literature_v1 import MetadataModel
from .insights_for_medical_literature_v1 import Message
from .insights_for_medical_literature_v1 import Order
from .insights_for_medical_literature_v1 import Passage
from .insights_for_medical_literature_v1 import Passages
from .insights_for_medical_literature_v1 import PassagesModel
from .insights_for_medical_literature_v1 import PossibleValues
from .insights_for_medical_literature_v1 import Qualifier
from .insights_for_medical_literature_v1 import Query
from .insights_for_medical_literature_v1 import Range
from .insights_for_medical_literature_v1 import RangeModel
from .insights_for_medical_literature_v1 import Ranges
from .insights_for_medical_literature_v1 import RankedDocLinks
from .insights_for_medical_literature_v1 import RankedDocument
from .insights_for_medical_literature_v1 import RelatedConceptModel
from .insights_for_medical_literature_v1 import RelatedConceptsModel
from .insights_for_medical_literature_v1 import RelationModel
from .insights_for_medical_literature_v1 import ReturnsModel
from .insights_for_medical_literature_v1 import SearchableConcept
from .insights_for_medical_literature_v1 import SearchMatchesModel
from .insights_for_medical_literature_v1 import SearchModel
from .insights_for_medical_literature_v1 import SentenceModel
from .insights_for_medical_literature_v1 import ServiceStatus
from .insights_for_medical_literature_v1 import SortEntry
from .insights_for_medical_literature_v1 import StringBuilder
from .insights_for_medical_literature_v1 import Supports
from .insights_for_medical_literature_v1 import TextSpan
from .insights_for_medical_literature_v1 import Title
from .insights_for_medical_literature_v1 import Typeahead
from .insights_for_medical_literature_v1 import TypesModel
from .insights_for_medical_literature_v1 import UnstructuredModel
from .insights_for_medical_literature_v1 import Values
from .insights_for_medical_literature_v1 import YearAndHits
from .insights_for_medical_literature_v1 import IMLException
